#include <QSettings>
#include "window.h"
CWindow::CWindow(QWidget *parent):QWidget(parent){    
    setupUi(this);
    banner = new CBanner;
    banner->setWindowFlags(Qt::ToolTip|Qt::WindowStaysOnTopHint);

    QObject::connect(pushButton_colorfondo,SIGNAL(clicked()),this,SLOT(setColorBanner()));
    QObject::connect(pushButton_colortexto,SIGNAL(clicked()),this,SLOT(setColorTextBanner()));
    QObject::connect(pushButton_fuentetexto,SIGNAL(clicked()),this,SLOT(setFontTextBanner()));
    QObject::connect(lineEdit_texto,SIGNAL(textChanged(const QString &)),this,SLOT(setTextBanner(const QString &)));
    QObject::connect(checkBox_marquesina,SIGNAL(clicked(bool)),this,SLOT(activarMarquesina(bool)));
    QObject::connect(pushButton_banner,SIGNAL(clicked()),this,SLOT(MostrarBanner()));
    QObject::connect(pushButton_empezar,SIGNAL(clicked()),this,SLOT(EjecutarMarquesina()));
    QObject::connect(pushButton_image,SIGNAL(clicked()),this,SLOT(setImage()));
    readSettings();
    banner->show();
}
void CWindow::EjecutarMarquesina(){
    static bool opc=true;
    if(opc){
        int val=spinBox_perm_marquesina->value();
        banner->setPermanencia(val);
        pushButton_empezar->setText("Detener");
        opc=false;
    }
    else{
        banner->setPermanencia(0);
        pushButton_empezar->setText("Empezar");
        opc=true;
    }
}
void CWindow::setTextBanner(const QString &ntexto){
    banner->setText(ntexto);
    banner->repaint();
}

void CWindow::setColorBanner(){
    QColor ncolor=QColorDialog::getColor( banner->palette().color(banner->backgroundRole()));
    if(ncolor.isValid())
        banner->setBackgroundColor(ncolor);
}
void CWindow::setImage(){
    QString filename;
    filename = QFileDialog::getOpenFileName(this,tr("Open Image"), "/home", tr("Image Files (*.png *.jpg *.bmp *.gif)"));
    banner->setBackgroundImage(filename);
}
void CWindow::MostrarBanner(){
    banner->show();
}
void CWindow::setFontTextBanner(){
    bool ok;
    QFont nfont=QFontDialog::getFont(&ok,banner->font());
    if(ok)
        banner->setFont(nfont);
}
void CWindow::activarMarquesina(bool value){
    banner->setMarquee(value);
    if(value){
        banner->setVelocityMarquee(horizontalSlider_velocidad->value());
        QObject::connect(horizontalSlider_velocidad,SIGNAL(valueChanged(int)),
                         banner,SLOT(setVelocityMarquee(int)));
    }
    else
        QObject::disconnect(horizontalSlider_velocidad,SIGNAL(valueChanged(int)),
                         banner,SLOT(setVelocityMarquee(int)));
}
void CWindow::setColorTextBanner(){
    QColor ncolor=QColorDialog::getColor(banner->getColorText());
    if(ncolor.isValid())
        banner->setColorText(ncolor);
        banner->repaint();
}
void CWindow::readSettings()
{
    QSettings settings("Banner", "banner");
    //geometria de la ventana controladora
    QPoint wpos = settings.value("pos", QPoint(200, 200)).toPoint();
    QSize wsize = settings.value("size", QSize(560,260)).toSize();
    //geometria de la ventana banner
    QPoint bpos= settings.value("bpos", QPoint(200, 500)).toPoint();
    QSize bsize= settings.value("bsize", QSize(560, 60)).toSize();
    //Fuente del texto de la ventana banner
    QString namef= settings.value("bnamefont",QString("Arial")).toString();
    QFont::Style stylef=(QFont::Style)settings.value("bstylefont",0).toInt();
    int weightf=settings.value("bweightfont",50).toInt();
    int sizef=settings.value("bsizefont",30).toInt();
    //color de fondo de la ventana banner
    int r=settings.value("bcolorr",120).toInt();
    int g=settings.value("bcolorg",120).toInt();
    int b=settings.value("bcolorb",120).toInt();

    //recuperar ultimo texto
    QString btexto=settings.value("texto",QString("Banner v1.1")).toString();

    move(wpos);
    resize(wsize);
    if(banner){
        banner->move(bpos);
        banner->resize(bsize);
        QFont f(namef,sizef,weightf);
        f.setStyle(stylef);
        banner->setFont(f);
        banner->setBackgroundColor(QColor(r,g,b));
        lineEdit_texto->setText(btexto);
    }
}
//esto se guarda en la maquina que esta ejecutando esta aplicacion, es como un *.ini//en nuestro caso se guarda en config/QTHERMO/qthermo
void CWindow::writeSettings()
{
    QSettings settings("Banner", "banner");
    settings.setValue("pos", pos());
    settings.setValue("size", size());
    if(banner){
        QColor fondo=banner->palette().color(banner->backgroundRole());
        settings.setValue("bpos",banner->pos());
        settings.setValue("bsize",banner->size());
        settings.setValue("bnamefont",banner->font().family());
        settings.setValue("bstylefont",banner->font().style());
        settings.setValue("bweightfont",banner->font().weight());
        settings.setValue("bsizefont",banner->font().pointSize());
        settings.setValue("bcolorr",fondo.red());
        settings.setValue("bcolorg",fondo.green());
        settings.setValue("bcolorb",fondo.blue());
        settings.setValue("texto",banner->getText());
    }
}
void CWindow::closeEvent(QCloseEvent *event){
    writeSettings();
}

